@@ -1,19 +1,24 @@
 //! A hash set implemented using `IndexMap`
 
 #[cfg(feature = "rayon")]
-pub use ::rayon::set as rayon;
+pub use rayon::set as rayon;
+
+#[cfg(not(has_std))]
+use std::vec::Vec;
+
+#[cfg(has_std)]
+use std::collections::hash_map::RandomState;
 
 use std::cmp::Ordering;
-use std::collections::hash_map::RandomState;
 use std::fmt;
-use std::iter::{FromIterator, Chain};
-use std::hash::{Hash, BuildHasher};
+use std::hash::{BuildHasher, Hash};
+use std::iter::{Chain, FromIterator};
 use std::ops::RangeFull;
 use std::ops::{BitAnd, BitOr, BitXor, Sub};
 use std::slice;
 use std::vec;
 
-use super::{IndexMap, Equivalent, Entries};
+use super::{Entries, Equivalent, IndexMap};
 
 type Bucket<T> = super::Bucket<T, ()>;
 
@@ -52,16 +57,22 @@ type Bucket<T> = super::Bucket<T, ()>;
 ///
 /// // Collects which letters appear in a sentence.
 /// let letters: IndexSet<_> = "a short treatise on fungi".chars().collect();
-/// 
+///
 /// assert!(letters.contains(&'s'));
 /// assert!(letters.contains(&'t'));
 /// assert!(letters.contains(&'u'));
 /// assert!(!letters.contains(&'y'));
 /// ```
 #[derive(Clone)]
+#[cfg(has_std)]
 pub struct IndexSet<T, S = RandomState> {
     map: IndexMap<T, (), S>,
 }
+#[cfg(not(has_std))]
+#[derive(Clone)]
+pub struct IndexSet<T, S> {
+    map: IndexMap<T, (), S>,
+}
 
 impl<T, S> Entries for IndexSet<T, S> {
     type Entry = Bucket<T>;
@@ -79,15 +90,17 @@ impl<T, S> Entries for IndexSet<T, S> {
     }
 
     fn with_entries<F>(&mut self, f: F)
-        where F: FnOnce(&mut [Self::Entry])
+    where
+        F: FnOnce(&mut [Self::Entry]),
     {
         self.map.with_entries(f);
     }
 }
 
 impl<T, S> fmt::Debug for IndexSet<T, S>
-    where T: fmt::Debug + Hash + Eq,
-          S: BuildHasher,
+where
+    T: fmt::Debug + Hash + Eq,
+    S: BuildHasher,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         if cfg!(not(feature = "test_debug")) {
@@ -99,10 +112,13 @@ impl<T, S> fmt::Debug for IndexSet<T, S>
     }
 }
 
+#[cfg(has_std)]
 impl<T> IndexSet<T> {
     /// Create a new set. (Does not allocate.)
     pub fn new() -> Self {
-        IndexSet { map: IndexMap::new() }
+        IndexSet {
+            map: IndexMap::new(),
+        }
     }
 
     /// Create a new set with capacity for `n` elements.
@@ -110,7 +126,9 @@ impl<T> IndexSet<T> {
     ///
     /// Computes in **O(n)** time.
     pub fn with_capacity(n: usize) -> Self {
-        IndexSet { map: IndexMap::with_capacity(n) }
+        IndexSet {
+            map: IndexMap::with_capacity(n),
+        }
     }
 }
 
@@ -120,9 +138,12 @@ impl<T, S> IndexSet<T, S> {
     ///
     /// Computes in **O(n)** time.
     pub fn with_capacity_and_hasher(n: usize, hash_builder: S) -> Self
-        where S: BuildHasher
+    where
+        S: BuildHasher,
     {
-        IndexSet { map: IndexMap::with_capacity_and_hasher(n, hash_builder) }
+        IndexSet {
+            map: IndexMap::with_capacity_and_hasher(n, hash_builder),
+        }
     }
 
     /// Return the number of elements in the set.
@@ -141,14 +162,18 @@ impl<T, S> IndexSet<T, S> {
 
     /// Create a new set with `hash_builder`
     pub fn with_hasher(hash_builder: S) -> Self
-        where S: BuildHasher
+    where
+        S: BuildHasher,
     {
-        IndexSet { map: IndexMap::with_hasher(hash_builder) }
+        IndexSet {
+            map: IndexMap::with_hasher(hash_builder),
+        }
     }
 
     /// Return a reference to the set's `BuildHasher`.
     pub fn hasher(&self) -> &S
-        where S: BuildHasher
+    where
+        S: BuildHasher,
     {
         self.map.hasher()
     }
@@ -160,8 +185,9 @@ impl<T, S> IndexSet<T, S> {
 }
 
 impl<T, S> IndexSet<T, S>
-    where T: Hash + Eq,
-          S: BuildHasher,
+where
+    T: Hash + Eq,
+    S: BuildHasher,
 {
     /// Remove all elements in the set, while preserving its capacity.
     ///
@@ -212,7 +238,7 @@ impl<T, S> IndexSet<T, S>
     /// Return an iterator over the values of the set, in their order
     pub fn iter(&self) -> Iter<T> {
         Iter {
-            iter: self.map.keys().iter
+            iter: self.map.keys().iter,
         }
     }
 
@@ -220,7 +246,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Values are produced in the same order that they appear in `self`.
     pub fn difference<'a, S2>(&'a self, other: &'a IndexSet<T, S2>) -> Difference<'a, T, S2>
-        where S2: BuildHasher
+    where
+        S2: BuildHasher,
     {
         Difference {
             iter: self.iter(),
@@ -233,9 +260,12 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Values from `self` are produced in their original order, followed by
     /// values from `other` in their original order.
-    pub fn symmetric_difference<'a, S2>(&'a self, other: &'a IndexSet<T, S2>)
-        -> SymmetricDifference<'a, T, S, S2>
-        where S2: BuildHasher
+    pub fn symmetric_difference<'a, S2>(
+        &'a self,
+        other: &'a IndexSet<T, S2>,
+    ) -> SymmetricDifference<'a, T, S, S2>
+    where
+        S2: BuildHasher,
     {
         SymmetricDifference {
             iter: self.difference(other).chain(other.difference(self)),
@@ -246,7 +276,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Values are produced in the same order that they appear in `self`.
     pub fn intersection<'a, S2>(&'a self, other: &'a IndexSet<T, S2>) -> Intersection<'a, T, S2>
-        where S2: BuildHasher
+    where
+        S2: BuildHasher,
     {
         Intersection {
             iter: self.iter(),
@@ -259,7 +290,8 @@ impl<T, S> IndexSet<T, S>
     /// Values from `self` are produced in their original order, followed by
     /// values that are unique to `other` in their original order.
     pub fn union<'a, S2>(&'a self, other: &'a IndexSet<T, S2>) -> Union<'a, T, S>
-        where S2: BuildHasher
+    where
+        S2: BuildHasher,
     {
         Union {
             iter: self.iter().chain(other.difference(self)),
@@ -270,7 +302,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(1)** time (average).
     pub fn contains<Q: ?Sized>(&self, value: &Q) -> bool
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.contains_key(value)
     }
@@ -280,14 +313,16 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(1)** time (average).
     pub fn get<Q: ?Sized>(&self, value: &Q) -> Option<&T>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.get_full(value).map(|(_, x, &())| x)
     }
 
     /// Return item index and value
     pub fn get_full<Q: ?Sized>(&self, value: &Q) -> Option<(usize, &T)>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.get_full(value).map(|(i, x, &())| (i, x))
     }
@@ -296,22 +331,27 @@ impl<T, S> IndexSet<T, S>
     /// equal to the given one. Returns the replaced value.
     ///
     /// Computes in **O(1)** time (average).
-    pub fn replace(&mut self, value: T) -> Option<T>
-    {
+    pub fn replace(&mut self, value: T) -> Option<T> {
         use super::map::Entry::*;
 
         match self.map.entry(value) {
-            Vacant(e) => { e.insert(()); None },
+            Vacant(e) => {
+                e.insert(());
+                None
+            }
             Occupied(e) => Some(e.replace_key()),
         }
     }
 
-    /// FIXME Same as .swap_remove
+    /// Remove the value from the set, and return `true` if it was present.
+    ///
+    /// **NOTE:** This is equivalent to `.swap_remove(value)`, if you want
+    /// to preserve the order of the values in the set, use `.shift_remove(value)`.
     ///
     /// Computes in **O(1)** time (average).
-    #[deprecated(note = "use `swap_remove` or `shift_remove`")]
     pub fn remove<Q: ?Sized>(&mut self, value: &Q) -> bool
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.swap_remove(value)
     }
@@ -326,7 +366,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(1)** time (average).
     pub fn swap_remove<Q: ?Sized>(&mut self, value: &Q) -> bool
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.swap_remove(value).is_some()
     }
@@ -341,17 +382,23 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(n)** time (average).
     pub fn shift_remove<Q: ?Sized>(&mut self, value: &Q) -> bool
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.shift_remove(value).is_some()
     }
 
-    /// FIXME Same as .swap_take
+    /// Removes and returns the value in the set, if any, that is equal to the
+    /// given one.
+    ///
+    /// **NOTE:** This is equivalent to `.swap_take(value)`, if you need to
+    /// preserve the order of the values in the set, use `.shift_take(value)`
+    /// instead.
     ///
     /// Computes in **O(1)** time (average).
-    #[deprecated(note = "use `swap_take` or `shift_take`")]
     pub fn take<Q: ?Sized>(&mut self, value: &Q) -> Option<T>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.swap_take(value)
     }
@@ -367,7 +414,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(1)** time (average).
     pub fn swap_take<Q: ?Sized>(&mut self, value: &Q) -> Option<T>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.swap_remove_full(value).map(|(_, x, ())| x)
     }
@@ -383,7 +431,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(n)** time (average).
     pub fn shift_take<Q: ?Sized>(&mut self, value: &Q) -> Option<T>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.shift_remove_full(value).map(|(_, x, ())| x)
     }
@@ -396,7 +445,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Return `None` if `value` was not in the set.
     pub fn swap_remove_full<Q: ?Sized>(&mut self, value: &Q) -> Option<(usize, T)>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.swap_remove_full(value).map(|(i, x, ())| (i, x))
     }
@@ -409,7 +459,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Return `None` if `value` was not in the set.
     pub fn shift_remove_full<Q: ?Sized>(&mut self, value: &Q) -> Option<(usize, T)>
-        where Q: Hash + Equivalent<T>,
+    where
+        Q: Hash + Equivalent<T>,
     {
         self.map.shift_remove_full(value).map(|(i, x, ())| (i, x))
     }
@@ -429,7 +480,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(n)** time (average).
     pub fn retain<F>(&mut self, mut keep: F)
-        where F: FnMut(&T) -> bool,
+    where
+        F: FnMut(&T) -> bool,
     {
         self.map.retain(move |x, &mut ()| keep(x))
     }
@@ -438,7 +490,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// See `sort_by` for details.
     pub fn sort(&mut self)
-        where T: Ord,
+    where
+        T: Ord,
     {
         self.map.sort_keys()
     }
@@ -447,7 +500,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// Computes in **O(n log n)** time and **O(n)** space. The sort is stable.
     pub fn sort_by<F>(&mut self, mut compare: F)
-        where F: FnMut(&T, &T) -> Ordering,
+    where
+        F: FnMut(&T, &T) -> Ordering,
     {
         self.map.sort_by(move |a, _, b, _| compare(a, b));
     }
@@ -457,7 +511,8 @@ impl<T, S> IndexSet<T, S>
     ///
     /// The sort is stable.
     pub fn sorted_by<F>(self, mut cmp: F) -> IntoIter<T>
-        where F: FnMut(&T, &T) -> Ordering
+    where
+        F: FnMut(&T, &T) -> Ordering,
     {
         IntoIter {
             iter: self.map.sorted_by(move |a, &(), b, &()| cmp(a, b)).iter,
@@ -510,7 +565,6 @@ impl<T, S> IndexSet<T, S> {
     }
 }
 
-
 /// An owning iterator over the items of a `IndexSet`.
 ///
 /// This `struct` is created by the [`into_iter`] method on [`IndexSet`]
@@ -547,7 +601,6 @@ impl<T: fmt::Debug> fmt::Debug for IntoIter<T> {
     }
 }
 
-
 /// An iterator over the items of a `IndexSet`.
 ///
 /// This `struct` is created by the [`iter`] method on [`IndexSet`].
@@ -579,7 +632,9 @@ impl<'a, T> ExactSizeIterator for Iter<'a, T> {
 
 impl<'a, T> Clone for Iter<'a, T> {
     fn clone(&self) -> Self {
-        Iter { iter: self.iter.clone() }
+        Iter {
+            iter: self.iter.clone(),
+        }
     }
 }
 
@@ -611,8 +666,9 @@ impl<'a, T> DoubleEndedIterator for Drain<'a, T> {
 }
 
 impl<'a, T, S> IntoIterator for &'a IndexSet<T, S>
-    where T: Hash + Eq,
-          S: BuildHasher,
+where
+    T: Hash + Eq,
+    S: BuildHasher,
 {
     type Item = &'a T;
     type IntoIter = Iter<'a, T>;
@@ -623,8 +679,9 @@ impl<'a, T, S> IntoIterator for &'a IndexSet<T, S>
 }
 
 impl<T, S> IntoIterator for IndexSet<T, S>
-    where T: Hash + Eq,
-          S: BuildHasher,
+where
+    T: Hash + Eq,
+    S: BuildHasher,
 {
     type Item = T;
     type IntoIter = IntoIter<T>;
@@ -637,49 +694,57 @@ impl<T, S> IntoIterator for IndexSet<T, S>
 }
 
 impl<T, S> FromIterator<T> for IndexSet<T, S>
-    where T: Hash + Eq,
-          S: BuildHasher + Default,
+where
+    T: Hash + Eq,
+    S: BuildHasher + Default,
 {
-    fn from_iter<I: IntoIterator<Item=T>>(iterable: I) -> Self {
+    fn from_iter<I: IntoIterator<Item = T>>(iterable: I) -> Self {
         let iter = iterable.into_iter().map(|x| (x, ()));
-        IndexSet { map: IndexMap::from_iter(iter) }
+        IndexSet {
+            map: IndexMap::from_iter(iter),
+        }
     }
 }
 
 impl<T, S> Extend<T> for IndexSet<T, S>
-    where T: Hash + Eq,
-          S: BuildHasher,
+where
+    T: Hash + Eq,
+    S: BuildHasher,
 {
-    fn extend<I: IntoIterator<Item=T>>(&mut self, iterable: I) {
+    fn extend<I: IntoIterator<Item = T>>(&mut self, iterable: I) {
         let iter = iterable.into_iter().map(|x| (x, ()));
         self.map.extend(iter);
     }
 }
 
 impl<'a, T, S> Extend<&'a T> for IndexSet<T, S>
-    where T: Hash + Eq + Copy + 'a,
-          S: BuildHasher,
+where
+    T: Hash + Eq + Copy + 'a,
+    S: BuildHasher,
 {
-    fn extend<I: IntoIterator<Item=&'a T>>(&mut self, iterable: I) {
+    fn extend<I: IntoIterator<Item = &'a T>>(&mut self, iterable: I) {
         let iter = iterable.into_iter().cloned(); // FIXME: use `copied` in Rust 1.36
         self.extend(iter);
     }
 }
 
-
 impl<T, S> Default for IndexSet<T, S>
-    where S: BuildHasher + Default,
+where
+    S: BuildHasher + Default,
 {
     /// Return an empty `IndexSet`
     fn default() -> Self {
-        IndexSet { map: IndexMap::default() }
+        IndexSet {
+            map: IndexMap::default(),
+        }
     }
 }
 
 impl<T, S1, S2> PartialEq<IndexSet<T, S2>> for IndexSet<T, S1>
-    where T: Hash + Eq,
-          S1: BuildHasher,
-          S2: BuildHasher
+where
+    T: Hash + Eq,
+    S1: BuildHasher,
+    S2: BuildHasher,
 {
     fn eq(&self, other: &IndexSet<T, S2>) -> bool {
         self.len() == other.len() && self.is_subset(other)
@@ -687,18 +752,21 @@ impl<T, S1, S2> PartialEq<IndexSet<T, S2>> for IndexSet<T, S1>
 }
 
 impl<T, S> Eq for IndexSet<T, S>
-    where T: Eq + Hash,
-          S: BuildHasher
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
 }
 
 impl<T, S> IndexSet<T, S>
-    where T: Eq + Hash,
-          S: BuildHasher
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     /// Returns `true` if `self` has no elements in common with `other`.
     pub fn is_disjoint<S2>(&self, other: &IndexSet<T, S2>) -> bool
-        where S2: BuildHasher
+    where
+        S2: BuildHasher,
     {
         if self.len() <= other.len() {
             self.iter().all(move |value| !other.contains(value))
@@ -709,20 +777,21 @@ impl<T, S> IndexSet<T, S>
 
     /// Returns `true` if all elements of `self` are contained in `other`.
     pub fn is_subset<S2>(&self, other: &IndexSet<T, S2>) -> bool
-        where S2: BuildHasher
+    where
+        S2: BuildHasher,
     {
         self.len() <= other.len() && self.iter().all(move |value| other.contains(value))
     }
 
     /// Returns `true` if all elements of `other` are contained in `self`.
     pub fn is_superset<S2>(&self, other: &IndexSet<T, S2>) -> bool
-        where S2: BuildHasher
+    where
+        S2: BuildHasher,
     {
         other.is_subset(self)
     }
 }
 
-
 /// A lazy iterator producing elements in the difference of `IndexSet`s.
 ///
 /// This `struct` is created by the [`difference`] method on [`IndexSet`].
@@ -736,8 +805,9 @@ pub struct Difference<'a, T: 'a, S: 'a> {
 }
 
 impl<'a, T, S> Iterator for Difference<'a, T, S>
-    where T: Eq + Hash,
-          S: BuildHasher
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     type Item = &'a T;
 
@@ -756,8 +826,9 @@ impl<'a, T, S> Iterator for Difference<'a, T, S>
 }
 
 impl<'a, T, S> DoubleEndedIterator for Difference<'a, T, S>
-    where T: Eq + Hash,
-          S: BuildHasher
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     fn next_back(&mut self) -> Option<Self::Item> {
         while let Some(item) = self.iter.next_back() {
@@ -771,20 +842,23 @@ impl<'a, T, S> DoubleEndedIterator for Difference<'a, T, S>
 
 impl<'a, T, S> Clone for Difference<'a, T, S> {
     fn clone(&self) -> Self {
-        Difference { iter: self.iter.clone(), ..*self }
+        Difference {
+            iter: self.iter.clone(),
+            ..*self
+        }
     }
 }
 
 impl<'a, T, S> fmt::Debug for Difference<'a, T, S>
-    where T: fmt::Debug + Eq + Hash,
-          S: BuildHasher
+where
+    T: fmt::Debug + Eq + Hash,
+    S: BuildHasher,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_list().entries(self.clone()).finish()
     }
 }
 
-
 /// A lazy iterator producing elements in the intersection of `IndexSet`s.
 ///
 /// This `struct` is created by the [`intersection`] method on [`IndexSet`].
@@ -798,8 +872,9 @@ pub struct Intersection<'a, T: 'a, S: 'a> {
 }
 
 impl<'a, T, S> Iterator for Intersection<'a, T, S>
-    where T: Eq + Hash,
-          S: BuildHasher
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     type Item = &'a T;
 
@@ -818,8 +893,9 @@ impl<'a, T, S> Iterator for Intersection<'a, T, S>
 }
 
 impl<'a, T, S> DoubleEndedIterator for Intersection<'a, T, S>
-    where T: Eq + Hash,
-          S: BuildHasher
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     fn next_back(&mut self) -> Option<Self::Item> {
         while let Some(item) = self.iter.next_back() {
@@ -833,20 +909,23 @@ impl<'a, T, S> DoubleEndedIterator for Intersection<'a, T, S>
 
 impl<'a, T, S> Clone for Intersection<'a, T, S> {
     fn clone(&self) -> Self {
-        Intersection { iter: self.iter.clone(), ..*self }
+        Intersection {
+            iter: self.iter.clone(),
+            ..*self
+        }
     }
 }
 
 impl<'a, T, S> fmt::Debug for Intersection<'a, T, S>
-    where T: fmt::Debug + Eq + Hash,
-          S: BuildHasher,
+where
+    T: fmt::Debug + Eq + Hash,
+    S: BuildHasher,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_list().entries(self.clone()).finish()
     }
 }
 
-
 /// A lazy iterator producing elements in the symmetric difference of `IndexSet`s.
 ///
 /// This `struct` is created by the [`symmetric_difference`] method on
@@ -859,9 +938,10 @@ pub struct SymmetricDifference<'a, T: 'a, S1: 'a, S2: 'a> {
 }
 
 impl<'a, T, S1, S2> Iterator for SymmetricDifference<'a, T, S1, S2>
-    where T: Eq + Hash,
-          S1: BuildHasher,
-          S2: BuildHasher,
+where
+    T: Eq + Hash,
+    S1: BuildHasher,
+    S2: BuildHasher,
 {
     type Item = &'a T;
 
@@ -874,16 +954,18 @@ impl<'a, T, S1, S2> Iterator for SymmetricDifference<'a, T, S1, S2>
     }
 
     fn fold<B, F>(self, init: B, f: F) -> B
-        where F: FnMut(B, Self::Item) -> B
+    where
+        F: FnMut(B, Self::Item) -> B,
     {
         self.iter.fold(init, f)
     }
 }
 
 impl<'a, T, S1, S2> DoubleEndedIterator for SymmetricDifference<'a, T, S1, S2>
-    where T: Eq + Hash,
-          S1: BuildHasher,
-          S2: BuildHasher,
+where
+    T: Eq + Hash,
+    S1: BuildHasher,
+    S2: BuildHasher,
 {
     fn next_back(&mut self) -> Option<Self::Item> {
         self.iter.next_back()
@@ -892,21 +974,23 @@ impl<'a, T, S1, S2> DoubleEndedIterator for SymmetricDifference<'a, T, S1, S2>
 
 impl<'a, T, S1, S2> Clone for SymmetricDifference<'a, T, S1, S2> {
     fn clone(&self) -> Self {
-        SymmetricDifference { iter: self.iter.clone() }
+        SymmetricDifference {
+            iter: self.iter.clone(),
+        }
     }
 }
 
 impl<'a, T, S1, S2> fmt::Debug for SymmetricDifference<'a, T, S1, S2>
-    where T: fmt::Debug + Eq + Hash,
-          S1: BuildHasher,
-          S2: BuildHasher,
+where
+    T: fmt::Debug + Eq + Hash,
+    S1: BuildHasher,
+    S2: BuildHasher,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_list().entries(self.clone()).finish()
     }
 }
 
-
 /// A lazy iterator producing elements in the union of `IndexSet`s.
 ///
 /// This `struct` is created by the [`union`] method on [`IndexSet`].
@@ -919,8 +1003,9 @@ pub struct Union<'a, T: 'a, S: 'a> {
 }
 
 impl<'a, T, S> Iterator for Union<'a, T, S>
-    where T: Eq + Hash,
-          S: BuildHasher,
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     type Item = &'a T;
 
@@ -933,15 +1018,17 @@ impl<'a, T, S> Iterator for Union<'a, T, S>
     }
 
     fn fold<B, F>(self, init: B, f: F) -> B
-        where F: FnMut(B, Self::Item) -> B
+    where
+        F: FnMut(B, Self::Item) -> B,
     {
         self.iter.fold(init, f)
     }
 }
 
 impl<'a, T, S> DoubleEndedIterator for Union<'a, T, S>
-    where T: Eq + Hash,
-          S: BuildHasher,
+where
+    T: Eq + Hash,
+    S: BuildHasher,
 {
     fn next_back(&mut self) -> Option<Self::Item> {
         self.iter.next_back()
@@ -950,24 +1037,27 @@ impl<'a, T, S> DoubleEndedIterator for Union<'a, T, S>
 
 impl<'a, T, S> Clone for Union<'a, T, S> {
     fn clone(&self) -> Self {
-        Union { iter: self.iter.clone() }
+        Union {
+            iter: self.iter.clone(),
+        }
     }
 }
 
 impl<'a, T, S> fmt::Debug for Union<'a, T, S>
-    where T: fmt::Debug + Eq + Hash,
-          S: BuildHasher,
+where
+    T: fmt::Debug + Eq + Hash,
+    S: BuildHasher,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_list().entries(self.clone()).finish()
     }
 }
 
-
 impl<'a, 'b, T, S1, S2> BitAnd<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
-    where T: Eq + Hash + Clone,
-          S1: BuildHasher + Default,
-          S2: BuildHasher,
+where
+    T: Eq + Hash + Clone,
+    S1: BuildHasher + Default,
+    S2: BuildHasher,
 {
     type Output = IndexSet<T, S1>;
 
@@ -980,9 +1070,10 @@ impl<'a, 'b, T, S1, S2> BitAnd<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
 }
 
 impl<'a, 'b, T, S1, S2> BitOr<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
-    where T: Eq + Hash + Clone,
-          S1: BuildHasher + Default,
-          S2: BuildHasher,
+where
+    T: Eq + Hash + Clone,
+    S1: BuildHasher + Default,
+    S2: BuildHasher,
 {
     type Output = IndexSet<T, S1>;
 
@@ -996,9 +1087,10 @@ impl<'a, 'b, T, S1, S2> BitOr<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
 }
 
 impl<'a, 'b, T, S1, S2> BitXor<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
-    where T: Eq + Hash + Clone,
-          S1: BuildHasher + Default,
-          S2: BuildHasher,
+where
+    T: Eq + Hash + Clone,
+    S1: BuildHasher + Default,
+    S2: BuildHasher,
 {
     type Output = IndexSet<T, S1>;
 
@@ -1012,9 +1104,10 @@ impl<'a, 'b, T, S1, S2> BitXor<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
 }
 
 impl<'a, 'b, T, S1, S2> Sub<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
-    where T: Eq + Hash + Clone,
-          S1: BuildHasher + Default,
-          S2: BuildHasher,
+where
+    T: Eq + Hash + Clone,
+    S1: BuildHasher + Default,
+    S2: BuildHasher,
 {
     type Output = IndexSet<T, S1>;
 
@@ -1026,7 +1119,6 @@ impl<'a, 'b, T, S1, S2> Sub<&'b IndexSet<T, S2>> for &'a IndexSet<T, S1>
     }
 }
 
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -1164,7 +1256,6 @@ mod tests {
         let not_present = [1, 3, 6, 9, 10];
         let mut set = IndexSet::with_capacity(insert.len());
 
-
         for (i, &elt) in enumerate(&insert) {
             assert_eq!(set.len(), i);
             set.insert(elt);
@@ -1211,7 +1302,7 @@ mod tests {
         }
         println!("{:?}", set);
         for &value in &remove {
-        //println!("{:?}", set);
+            //println!("{:?}", set);
             let index = set.get_full(&value).unwrap().0;
             assert_eq!(set.swap_remove_full(&value), Some((index, value)));
         }
@@ -1310,8 +1401,9 @@ mod tests {
         use std::iter::empty;
 
         fn check<'a, I1, I2>(iter1: I1, iter2: I2)
-            where I1: Iterator<Item = &'a i32>,
-                  I2: Iterator<Item = i32>,
+        where
+            I1: Iterator<Item = &'a i32>,
+            I2: Iterator<Item = i32>,
         {
             assert!(iter1.cloned().eq(iter2));
         }
@@ -1346,7 +1438,10 @@ mod tests {
 
         check(set_c.difference(&set_d), 0..3);
         check(set_d.difference(&set_c), (6..9).rev());
-        check(set_c.symmetric_difference(&set_d), (0..3).chain((6..9).rev()));
+        check(
+            set_c.symmetric_difference(&set_d),
+            (0..3).chain((6..9).rev()),
+        );
         check(set_d.symmetric_difference(&set_c), (6..9).rev().chain(0..3));
         check(set_c.intersection(&set_d), 3..6);
         check(set_d.intersection(&set_c), (3..6).rev());
